@@ -14,7 +14,7 @@ class BaseComponent:
     input_defs: List[InputDefinition] = []
     output_defs: List[OutputDefinition] = []
     config_schema: Dict[str, Field] = {}
-    required_resource_keys: Set[str] = set()
+    required_resource_keys: List[str] = {}
     tags: Dict[str, str] = {}
 
     @classmethod
@@ -29,9 +29,20 @@ class BaseComponent:
         Raises:
             NotImplementedError: The compute hook is not implemented by default.
         """
+        # Load the required resources defined in the required_resource_keys attribute
+        resources = {
+            resource_key: resource
+            for resource_key, resource in step_context.resources._asdict().items()
+            if resource_key in cls.required_resource_keys
+        }
+
         # Run the compute function ("cls.compute_function" needs to be defined by the children)
-        # The inputs of the previous and op config are injected into the compute function
-        results = getattr(cls, cls.compute_function)(**inputs, **step_context.op_config)
+        # The inputs of the previous op, resources and op config are injected into the compute function
+        results = getattr(cls, cls.compute_function)(
+            **inputs,
+            **resources,
+            **step_context.op_config,
+        )
 
         # If the results are not a sequence, wrap it in a list
         if not isinstance(results, Sequence):
