@@ -1,20 +1,24 @@
-from qdk.inference.base import InferenceComponent
-from qdk.dagster_types import MLFlowRunType, DataFrameType, SeriesType
-from qdk.mlflow import MLFlowRun
-from dagster import InputDefinition, OutputDefinition
-from pandas import DataFrame, Series
-from dask.dataframe import DataFrame as DaskDataFrame, Series as DaskSeries
 from typing import Union
 
+from dagster import InputDefinition, OutputDefinition
+from dask.dataframe import DataFrame as DaskDataFrame
+from dask.dataframe import Series as DaskSeries
+from pandas import DataFrame, Series
+from qdk.dagster_types import DataFrameType, MLFlowRunType, SeriesType
+from qdk.inference.base import BaseInference
+from qdk.mlflow import MLFlowRun
 
-class MLFlowInferenceComponent(InferenceComponent):
+
+class MLFlowInference(BaseInference):
     compute_function = "predict"
     input_defs = [
         InputDefinition("X", DataFrameType),
         InputDefinition("mlflow_run", MLFlowRunType),
         InputDefinition("y_true", SeriesType, default_value=None),
     ]
-    output_defs = [OutputDefinition(DataFrameType, "X_hat")]
+    output_defs = [
+        OutputDefinition(DataFrameType, "X_hat"),
+    ]
 
     @classmethod
     def predict(
