@@ -1,18 +1,16 @@
 import multiprocessing
-from typing import List, Optional, Tuple, Union
+from typing import List, Tuple, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Field, OutputDefinition
+from dagster import OutputDefinition
 from gensim.models.doc2vec import Doc2Vec, TaggedDocument
 from pandas.core.frame import DataFrame
 from qdk.dagster_types import DataFrameType, ModelType
-from qdk.training.word2vec import Word2VecTrainingComponent
-
-from sklearn.base import BaseEstimator
+from qdk.training.word2vec import Word2VecTrainer
 
 
-class Doc2VecTrainingComponent(Word2VecTrainingComponent):
+class Doc2VecTrainer(Word2VecTrainer):
     output_defs = [
         OutputDefinition(
             ModelType,
