@@ -7,7 +7,7 @@ from qdk.base import BaseComponent
 from qdk.dagster_types import DataFrameType
 
 
-class TransformComponent(BaseComponent):
+class BaseTransformer(BaseComponent):
     compute_function = "transform"
     tags = {
         "kind": "transform",
